@@ -84,6 +84,7 @@ Out of the box implementation of the Construct without any override will set the
 
 * Configure least privilege access IAM role for Lambda function
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
+* Enable X-Ray Tracing
 
 ## Architecture
 
@@ -101,8 +102,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -119,7 +120,7 @@ class EventsRuleToLambda(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
         event_rule_props: aws_cdk.aws_events.RuleProps,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
@@ -147,12 +148,12 @@ class EventsRuleToLambda(
 
         jsii.create(EventsRuleToLambda, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="eventsRule")
     def events_rule(self) -> aws_cdk.aws_events.Rule:
         return jsii.get(self, "eventsRule")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "lambdaFunction")
@@ -187,7 +188,7 @@ class EventsRuleToLambdaProps:
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "event_rule_props": event_rule_props,
         }
         if existing_lambda_obj is not None:
@@ -202,7 +203,9 @@ class EventsRuleToLambdaProps:
         default
         :default: - None
         """
-        return self._values.get("event_rule_props")
+        result = self._values.get("event_rule_props")
+        assert result is not None, "Required property 'event_rule_props' is missing"
+        return result
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -211,7 +214,8 @@ class EventsRuleToLambdaProps:
         default
         :default: - None
         """
-        return self._values.get("existing_lambda_obj")
+        result = self._values.get("existing_lambda_obj")
+        return result
 
     @builtins.property
     def lambda_function_props(
@@ -222,12 +226,13 @@ class EventsRuleToLambdaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("lambda_function_props")
+        result = self._values.get("lambda_function_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
