@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_iam._jsii
@@ -17,9 +17,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-events-rule-lambda",
-    "1.60.0",
+    "1.61.1",
     __name__[0:-6],
-    "aws-events-rule-lambda@1.60.0.jsii.tgz",
+    "aws-events-rule-lambda@1.61.1.jsii.tgz",
 )
 
 __all__ = [
